Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RobotLister ¶
type RobotLister interface {
// List lists all Robots in the indexer.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Robot, err error)
// Robots returns an object that can list and get Robots.
Robots(namespace string) RobotNamespaceLister
RobotListerExpansion
}
RobotLister helps list Robots. All objects returned here must be treated as read-only.
func NewRobotLister ¶
func NewRobotLister(indexer cache.Indexer) RobotLister
NewRobotLister returns a new RobotLister.
type RobotListerExpansion ¶
type RobotListerExpansion interface{}
RobotListerExpansion allows custom methods to be added to RobotLister.
type RobotNamespaceLister ¶
type RobotNamespaceLister interface {
// List lists all Robots in the indexer for a given namespace.
// Objects returned here must be treated as read-only.
List(selector labels.Selector) (ret []*v1alpha1.Robot, err error)
// Get retrieves the Robot from the indexer for a given namespace and name.
// Objects returned here must be treated as read-only.
Get(name string) (*v1alpha1.Robot, error)
RobotNamespaceListerExpansion
}
RobotNamespaceLister helps list and get Robots. All objects returned here must be treated as read-only.
type RobotNamespaceListerExpansion ¶
type RobotNamespaceListerExpansion interface{}
RobotNamespaceListerExpansion allows custom methods to be added to RobotNamespaceLister.
Click to show internal directories.
Click to hide internal directories.